/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import { LegendDisplay } from '@kbn/expression-partition-vis-plugin/common';
import { LegendSize } from '@kbn/visualizations-plugin/common';

const mockUiStateGet = jest.fn().mockReturnValue(() => false);

export const samplePieVis = {
  type: {
    name: 'pie',
    title: 'Pie',
    description: 'Compare parts of a whole',
    icon: 'visPie',
    stage: 'production',
    options: {
      showTimePicker: true,
      showFilterBar: true,
      showIndexSelection: true,
      hierarchicalData: false,
    },
    visConfig: {
      defaults: {
        type: 'pie',
        addTooltip: true,
        legendDisplay: LegendDisplay.SHOW,
        legendPosition: 'right',
        isDonut: true,
        nestedLegend: true,
        truncateLegend: true,
        maxLegendLines: 1,
        distinctColors: false,
        palette: 'kibana_palette',
        labels: {
          show: false,
          values: true,
          last_level: true,
          valuesFormat: 'percent',
          percentDecimals: 2,
          truncate: 100,
        },
      },
    },
    editorConfig: {
      enableDataViewChange: true,
      collections: {
        legendPositions: [
          {
            text: 'Top',
            value: 'top',
          },
          {
            text: 'Left',
            value: 'left',
          },
          {
            text: 'Right',
            value: 'right',
          },
          {
            text: 'Bottom',
            value: 'bottom',
          },
        ],
      },
      schemas: {
        all: [
          {
            group: 'metrics',
            name: 'metric',
            title: 'Slice size',
            min: 1,
            max: 1,
            aggFilter: ['sum', 'count', 'cardinality', 'top_hits'],
            defaults: [
              {
                schema: 'metric',
                type: 'count',
              },
            ],
            editor: false,
            params: [],
          },
          {
            group: 'buckets',
            name: 'segment',
            title: 'Split slices',
            min: 0,
            max: null,
            aggFilter: [
              '!geotile_grid',
              '!filter',
              '!sampler',
              '!diversified_sampler',
              '!rare_terms',
              '!multi_terms',
              '!significant_text',
            ],
            editor: false,
            params: [],
          },
          {
            group: 'buckets',
            name: 'split',
            title: 'Split chart',
            mustBeFirst: true,
            min: 0,
            max: 1,
            aggFilter: [
              '!geotile_grid',
              '!filter',
              '!sampler',
              '!diversified_sampler',
              '!rare_terms',
              '!multi_terms',
              '!significant_text',
            ],
            params: [
              {
                name: 'row',
                default: true,
              },
            ],
            editor: false,
          },
        ],
        buckets: [null, null],
        metrics: [null],
      },
    },
    hidden: false,
    hierarchicalData: true,
  },
  title: '[Flights] Airline Carrier',
  description: '',
  params: {
    type: 'pie',
    addTooltip: true,
    legendDisplay: LegendDisplay.SHOW,
    legendPosition: 'right',
    legendSize: LegendSize.LARGE,
    isDonut: true,
    labels: {
      show: true,
      values: true,
      last_level: true,
      truncate: 100,
    },
  },
  data: {
    indexPattern: { id: '123' },
    searchSource: {
      id: 'data_source1',
      requestStartHandlers: [],
      inheritOptions: {},
      history: [],
      fields: {
        filter: [],
        query: {
          query: '',
          language: 'kuery',
        },
        index: {
          id: 'd3d7af60-4c81-11e8-b3d7-01146121b73d',
          title: 'kibana_sample_data_flights',
          fieldFormatMap: {
            AvgTicketPrice: {
              id: 'number',
              params: {
                parsedUrl: {
                  origin: 'http://localhost:5801',
                  pathname: '/app/visualize',
                  basePath: '',
                },
                pattern: '$0,0.[00]',
              },
            },
            hour_of_day: {
              id: 'number',
              params: {
                pattern: '00',
              },
            },
          },
          fields: [
            {
              count: 0,
              name: 'AvgTicketPrice',
              type: 'number',
              esTypes: ['float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'Cancelled',
              type: 'boolean',
              esTypes: ['boolean'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'Carrier',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'Dest',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DestAirportID',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DestCityName',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DestCountry',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DestLocation',
              type: 'geo_point',
              esTypes: ['geo_point'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DestRegion',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DestWeather',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DistanceKilometers',
              type: 'number',
              esTypes: ['float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'DistanceMiles',
              type: 'number',
              esTypes: ['float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'FlightDelay',
              type: 'boolean',
              esTypes: ['boolean'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'FlightDelayMin',
              type: 'number',
              esTypes: ['integer'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'FlightDelayType',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'FlightNum',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'FlightTimeHour',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'FlightTimeMin',
              type: 'number',
              esTypes: ['float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'Origin',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'OriginAirportID',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'OriginCityName',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'OriginCountry',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'OriginLocation',
              type: 'geo_point',
              esTypes: ['geo_point'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'OriginRegion',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'OriginWeather',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: '_id',
              type: 'string',
              esTypes: ['_id'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_index',
              type: 'string',
              esTypes: ['_index'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_score',
              type: 'number',
              scripted: false,
              searchable: false,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_source',
              type: '_source',
              esTypes: ['_source'],
              scripted: false,
              searchable: false,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_type',
              type: 'string',
              esTypes: ['_type'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'dayOfWeek',
              type: 'number',
              esTypes: ['integer'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'timestamp',
              type: 'date',
              esTypes: ['date'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              script: "doc['timestamp'].value.getHour()",
              lang: 'painless',
              name: 'hour_of_day',
              type: 'number',
              scripted: true,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
          ],
          timeFieldName: 'timestamp',
          metaFields: ['_source', '_id', '_type', '_index', '_score'],
          version: 'WzM1LDFd',
          originalSavedObjectBody: {
            title: 'kibana_sample_data_flights',
            timeFieldName: 'timestamp',
            fields:
              '[{"count":0,"name":"AvgTicketPrice","type":"number","esTypes":["float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"Cancelled","type":"boolean","esTypes":["boolean"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"Carrier","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"Dest","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DestAirportID","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DestCityName","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DestCountry","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DestLocation","type":"geo_point","esTypes":["geo_point"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DestRegion","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DestWeather","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DistanceKilometers","type":"number","esTypes":["float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"DistanceMiles","type":"number","esTypes":["float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"FlightDelay","type":"boolean","esTypes":["boolean"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"FlightDelayMin","type":"number","esTypes":["integer"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"FlightDelayType","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"FlightNum","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"FlightTimeHour","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"FlightTimeMin","type":"number","esTypes":["float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"Origin","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"OriginAirportID","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"OriginCityName","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"OriginCountry","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"OriginLocation","type":"geo_point","esTypes":["geo_point"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"OriginRegion","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"OriginWeather","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"_id","type":"string","esTypes":["_id"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":false},{"count":0,"name":"_index","type":"string","esTypes":["_index"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":false},{"count":0,"name":"_score","type":"number","scripted":false,"searchable":false,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"_source","type":"_source","esTypes":["_source"],"scripted":false,"searchable":false,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"_type","type":"string","esTypes":["_type"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":false},{"count":0,"name":"dayOfWeek","type":"number","esTypes":["integer"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"timestamp","type":"date","esTypes":["date"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"script":"doc[\'timestamp\'].value.getHour()","lang":"painless","name":"hour_of_day","type":"number","scripted":true,"searchable":true,"aggregatable":true,"readFromDocValues":false}]',
            fieldFormatMap:
              '{"AvgTicketPrice":{"id":"number","params":{"parsedUrl":{"origin":"http://localhost:5801","pathname":"/app/visualize","basePath":""},"pattern":"$0,0.[00]"}},"hour_of_day":{"id":"number","params":{"parsedUrl":{"origin":"http://localhost:5801","pathname":"/app/visualize","basePath":""},"pattern":"00"}}}',
          },
          shortDotsEnable: false,
          fieldFormats: {
            fieldFormats: {},
            defaultMap: {
              ip: {
                id: 'ip',
                params: {},
              },
              date: {
                id: 'date',
                params: {},
              },
              date_nanos: {
                id: 'date_nanos',
                params: {},
                es: true,
              },
              number: {
                id: 'number',
                params: {},
              },
              boolean: {
                id: 'boolean',
                params: {},
              },
              _source: {
                id: '_source',
                params: {},
              },
              _default_: {
                id: 'string',
                params: {},
              },
            },
            metaParamsOptions: {},
          },
        },
      },
      dependencies: {
        legacy: {
          loadingCount$: {
            _isScalar: false,
            observers: [
              {
                closed: false,
                _parentOrParents: {
                  closed: false,
                  _parentOrParents: {
                    closed: false,
                    _parentOrParents: {
                      closed: false,
                      _parentOrParents: {
                        closed: false,
                        _parentOrParents: {
                          closed: false,
                          _parentOrParents: {
                            closed: false,
                            _parentOrParents: {
                              closed: false,
                              _parentOrParents: null,
                              _subscriptions: [null],
                              syncErrorValue: null,
                              syncErrorThrown: false,
                              syncErrorThrowable: true,
                              isStopped: false,
                              destination: {
                                closed: false,
                                _parentOrParents: null,
                                _subscriptions: null,
                                syncErrorValue: null,
                                syncErrorThrown: false,
                                syncErrorThrowable: false,
                                isStopped: false,
                                destination: {
                                  closed: true,
                                },
                                _context: {},
                              },
                            },
                            _subscriptions: [null],
                            syncErrorValue: null,
                            syncErrorThrown: false,
                            syncErrorThrowable: true,
                            isStopped: false,
                            count: 1,
                          },
                          _subscriptions: [null],
                          syncErrorValue: null,
                          syncErrorThrown: false,
                          syncErrorThrowable: true,
                          isStopped: false,
                          hasPrev: true,
                          prev: 0,
                        },
                        _subscriptions: [null],
                        syncErrorValue: null,
                        syncErrorThrown: false,
                        syncErrorThrowable: false,
                        isStopped: false,
                        parent: {
                          closed: true,
                          _parentOrParents: null,
                          _subscriptions: null,
                          syncErrorValue: null,
                          syncErrorThrown: false,
                          syncErrorThrowable: true,
                          isStopped: true,
                          concurrent: 1,
                          hasCompleted: true,
                          buffer: [],
                          active: 1,
                          index: 2,
                        },
                      },
                      _subscriptions: [null],
                      syncErrorValue: null,
                      syncErrorThrown: false,
                      syncErrorThrowable: false,
                      isStopped: false,
                      parent: {
                        closed: true,
                        _parentOrParents: null,
                        _subscriptions: null,
                        syncErrorValue: null,
                        syncErrorThrown: false,
                        syncErrorThrowable: false,
                        isStopped: true,
                        concurrent: 1,
                        hasCompleted: true,
                        buffer: [
                          {
                            _isScalar: false,
                          },
                        ],
                        active: 1,
                        index: 1,
                      },
                    },
                    _subscriptions: [
                      {
                        closed: false,
                        _subscriptions: [
                          {
                            closed: false,
                            _subscriptions: null,
                            subject: {
                              _isScalar: false,
                              observers: [
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 13,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 1,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 1,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 3,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                null,
                              ],
                              closed: false,
                              isStopped: false,
                              hasError: false,
                              thrownError: null,
                            },
                          },
                        ],
                        syncErrorValue: null,
                        syncErrorThrown: false,
                        syncErrorThrowable: false,
                        isStopped: false,
                      },
                      null,
                    ],
                    syncErrorValue: null,
                    syncErrorThrown: false,
                    syncErrorThrowable: false,
                    isStopped: false,
                    seenValue: false,
                  },
                  _subscriptions: [null],
                  syncErrorValue: null,
                  syncErrorThrown: false,
                  syncErrorThrowable: false,
                  isStopped: false,
                },
                _subscriptions: [
                  {
                    closed: false,
                    _subscriptions: null,
                  },
                ],
                syncErrorValue: null,
                syncErrorThrown: false,
                syncErrorThrowable: false,
                isStopped: false,
                hasKey: true,
                key: 0,
              },
            ],
            closed: false,
            isStopped: false,
            hasError: false,
            thrownError: null,
            _value: 0,
          },
        },
      },
    },
    aggs: {
      typesRegistry: {},
      getResponseAggs: () => [
        {
          id: '1',
          enabled: true,
          type: { name: 'count' },
          params: {},
          schema: 'metric',
          toSerializedFieldFormat: () => ({
            id: 'number',
          }),
        },
        {
          id: '2',
          enabled: true,
          type: { name: 'terms' },
          params: {
            field: 'Carrier',
            orderBy: '1',
            order: 'desc',
            size: 5,
            otherBucket: false,
            otherBucketLabel: 'Other',
            missingBucket: false,
            missingBucketLabel: 'Missing',
          },
          schema: 'segment',
          toSerializedFieldFormat: () => ({
            id: 'terms',
            params: {
              id: 'string',
              otherBucketLabel: 'Other',
              missingBucketLabel: 'Missing',
              parsedUrl: {
                origin: 'http://localhost:5801',
                pathname: '/app/visualize',
                basePath: '',
              },
            },
          }),
        },
      ],
      aggs: [],
    },
  },
  isHierarchical: () => true,
  uiState: {
    vis: {
      legendOpen: false,
    },
    get: mockUiStateGet,
  },
};
