/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import { LegendSize } from '@kbn/visualizations-plugin/common';

const mockUiStateGet = jest.fn().mockReturnValue(() => false);

export const sampleAreaVis = {
  type: {
    name: 'area',
    title: 'Area',
    description: 'Emphasize the quantity beneath a line chart',
    icon: 'visArea',
    stage: 'production',
    options: {
      showTimePicker: true,
      showFilterBar: true,
      showIndexSelection: true,
      hierarchicalData: false,
    },
    visConfig: {
      defaults: {
        type: 'area',
        grid: {
          categoryLines: false,
        },
        categoryAxes: [
          {
            id: 'CategoryAxis-1',
            type: 'category',
            position: 'bottom',
            show: true,
            style: {},
            scale: {
              type: 'linear',
            },
            labels: {
              show: true,
              filter: true,
              truncate: 100,
            },
            title: {},
          },
        ],
        valueAxes: [
          {
            id: 'ValueAxis-1',
            name: 'LeftAxis-1',
            type: 'value',
            position: 'left',
            show: true,
            style: {},
            scale: {
              type: 'linear',
              mode: 'normal',
            },
            labels: {
              show: true,
              rotate: 0,
              filter: false,
              truncate: 100,
            },
            title: {
              text: 'Count',
            },
          },
        ],
        seriesParams: [
          {
            show: true,
            type: 'area',
            mode: 'stacked',
            data: {
              label: 'Count',
              id: '1',
            },
            drawLinesBetweenPoints: true,
            lineWidth: 2,
            showCircles: true,
            circlesRadius: 3,
            interpolate: 'linear',
            valueAxis: 'ValueAxis-1',
          },
        ],
        addTooltip: true,
        addLegend: true,
        legendPosition: 'right',
        times: [],
        addTimeMarker: false,
        truncateLegend: true,
        maxLegendLines: 1,
        thresholdLine: {
          show: false,
          value: 10,
          width: 1,
          style: 'full',
          color: '#E7664C',
        },
        labels: {},
        palette: {
          name: 'default',
        },
        fillOpacity: 0.5,
      },
    },
    editorConfig: {
      enableDataViewChange: true,
      optionTabs: [
        {
          name: 'advanced',
          title: 'Metrics & axes',
        },
        {
          name: 'options',
          title: 'Panel settings',
        },
      ],
      schemas: {
        all: [
          {
            group: 'metrics',
            name: 'metric',
            title: 'Y-axis',
            aggFilter: ['!geo_centroid', '!geo_bounds'],
            min: 1,
            defaults: [
              {
                schema: 'metric',
                type: 'count',
              },
            ],
            max: null,
            editor: false,
            params: [],
          },
          {
            group: 'metrics',
            name: 'radius',
            title: 'Dot size',
            min: 0,
            max: 1,
            aggFilter: ['count', 'avg', 'sum', 'min', 'max', 'cardinality'],
            editor: false,
            params: [],
          },
          {
            group: 'buckets',
            name: 'segment',
            title: 'X-axis',
            min: 0,
            max: 1,
            aggFilter: [
              '!geotile_grid',
              '!filter',
              '!sampler',
              '!diversified_sampler',
              '!rare_terms',
              '!multi_terms',
              '!significant_text',
            ],
            editor: false,
            params: [],
          },
          {
            group: 'buckets',
            name: 'group',
            title: 'Split series',
            min: 0,
            max: 3,
            aggFilter: [
              '!geotile_grid',
              '!filter',
              '!sampler',
              '!diversified_sampler',
              '!rare_terms',
              '!multi_terms',
              '!significant_text',
            ],
            editor: false,
            params: [],
          },
          {
            group: 'buckets',
            name: 'split',
            title: 'Split chart',
            min: 0,
            max: 1,
            aggFilter: [
              '!geotile_grid',
              '!filter',
              '!sampler',
              '!diversified_sampler',
              '!rare_terms',
              '!multi_terms',
              '!significant_text',
            ],
            params: [
              {
                name: 'row',
                default: true,
              },
            ],
            editor: false,
          },
        ],
        buckets: [null, null, null],
        metrics: [null, null],
      },
    },
    hidden: false,
    hierarchicalData: false,
  },
  title: '[eCommerce] Sales by Category',
  description: '',
  params: {
    type: 'area',
    grid: {
      categoryLines: false,
      style: {
        color: '#eee',
      },
    },
    categoryAxes: [
      {
        id: 'CategoryAxis-1',
        type: 'category',
        position: 'bottom',
        show: true,
        style: {},
        scale: {
          type: 'linear',
        },
        labels: {
          show: true,
          truncate: 100,
        },
        title: {},
      },
    ],
    valueAxes: [
      {
        id: 'ValueAxis-1',
        name: 'LeftAxis-1',
        type: 'value',
        position: 'left',
        show: true,
        style: {},
        scale: {
          type: 'linear',
          mode: 'normal',
        },
        labels: {
          show: true,
          rotate: 0,
          filter: false,
          truncate: 100,
        },
        title: {
          text: 'Sum of total_quantity',
        },
      },
    ],
    seriesParams: [
      {
        show: 'true',
        type: 'area',
        mode: 'stacked',
        data: {
          label: 'Sum of total_quantity',
          id: '1',
        },
        drawLinesBetweenPoints: true,
        showCircles: true,
        circlesRadius: 5,
        interpolate: 'linear',
        valueAxis: 'ValueAxis-1',
      },
    ],
    addTooltip: true,
    addLegend: true,
    legendPosition: 'top',
    legendSize: LegendSize.SMALL,
    times: [],
    addTimeMarker: false,
    truncateLegend: true,
    maxLegendLines: 1,
    thresholdLine: {
      show: false,
      value: 10,
      width: 1,
      style: 'full',
      color: '#E7664C',
    },
    palette: {
      name: 'default',
    },
    labels: {},
    dimensions: {
      x: {
        accessor: 0,
        format: {
          id: 'date',
          params: {
            pattern: 'YYYY-MM-DD HH:mm',
          },
        },
        params: {
          date: true,
          interval: 43200000,
          format: 'YYYY-MM-DD HH:mm',
          bounds: {
            min: '2020-09-30T12:41:13.795Z',
            max: '2020-10-15T17:00:00.000Z',
          },
        },
        label: 'order_date per 12 hours',
        aggType: 'date_histogram',
      },
      y: [
        {
          accessor: 2,
          format: {
            id: 'number',
            params: {
              parsedUrl: {
                origin: 'http://localhost:5801',
                pathname: '/app/visualize',
                basePath: '',
              },
            },
          },
          params: {},
          label: 'Sum of total_quantity',
          aggType: 'sum',
        },
      ],
      series: [
        {
          accessor: 1,
          format: {
            id: 'terms',
            params: {
              id: 'string',
              otherBucketLabel: 'Other',
              missingBucketLabel: 'Missing',
            },
          },
          params: {},
          label: 'category.keyword: Descending',
          aggType: 'terms',
        },
      ],
    },
  },
  data: {
    searchSource: {
      id: 'data_source1',
      requestStartHandlers: [],
      inheritOptions: {},
      history: [],
      fields: {
        query: {
          query: '',
          language: 'kuery',
        },
        filter: [],
        index: {
          id: 'ff959d40-b880-11e8-a6d9-e546fe2bba5f',
          title: 'kibana_sample_data_ecommerce',
          fieldFormatMap: {
            taxful_total_price: {
              id: 'number',
              params: {
                pattern: '$0,0.[00]',
              },
            },
          },
          fields: [
            {
              count: 0,
              name: '_id',
              type: 'string',
              esTypes: ['_id'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_index',
              type: 'string',
              esTypes: ['_index'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_score',
              type: 'number',
              scripted: false,
              searchable: false,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_source',
              type: '_source',
              esTypes: ['_source'],
              scripted: false,
              searchable: false,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: '_type',
              type: 'string',
              esTypes: ['_type'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'category',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'category.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'category',
                },
              },
            },
            {
              count: 0,
              name: 'currency',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'customer_birth_date',
              type: 'date',
              esTypes: ['date'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'customer_first_name',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'customer_first_name.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'customer_first_name',
                },
              },
            },
            {
              count: 0,
              name: 'customer_full_name',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'customer_full_name.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'customer_full_name',
                },
              },
            },
            {
              count: 0,
              name: 'customer_gender',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'customer_id',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'customer_last_name',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'customer_last_name.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'customer_last_name',
                },
              },
            },
            {
              count: 0,
              name: 'customer_phone',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'day_of_week',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'day_of_week_i',
              type: 'number',
              esTypes: ['integer'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'email',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'event.dataset',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'geoip.city_name',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'geoip.continent_name',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'geoip.country_iso_code',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'geoip.location',
              type: 'geo_point',
              esTypes: ['geo_point'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'geoip.region_name',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'manufacturer',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'manufacturer.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'manufacturer',
                },
              },
            },
            {
              count: 0,
              name: 'order_date',
              type: 'date',
              esTypes: ['date'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'order_id',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products._id',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'products._id.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'products._id',
                },
              },
            },
            {
              count: 0,
              name: 'products.base_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.base_unit_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.category',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'products.category.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'products.category',
                },
              },
            },
            {
              count: 0,
              name: 'products.created_on',
              type: 'date',
              esTypes: ['date'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.discount_amount',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.discount_percentage',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.manufacturer',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'products.manufacturer.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'products.manufacturer',
                },
              },
            },
            {
              count: 0,
              name: 'products.min_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.product_id',
              type: 'number',
              esTypes: ['long'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.product_name',
              type: 'string',
              esTypes: ['text'],
              scripted: false,
              searchable: true,
              aggregatable: false,
              readFromDocValues: false,
            },
            {
              count: 0,
              name: 'products.product_name.keyword',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
              subType: {
                multi: {
                  parent: 'products.product_name',
                },
              },
            },
            {
              count: 0,
              name: 'products.quantity',
              type: 'number',
              esTypes: ['integer'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.sku',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.tax_amount',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.taxful_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.taxless_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'products.unit_discount_amount',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'sku',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'taxful_total_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'taxless_total_price',
              type: 'number',
              esTypes: ['half_float'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'total_quantity',
              type: 'number',
              esTypes: ['integer'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'total_unique_products',
              type: 'number',
              esTypes: ['integer'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'type',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
            {
              count: 0,
              name: 'user',
              type: 'string',
              esTypes: ['keyword'],
              scripted: false,
              searchable: true,
              aggregatable: true,
              readFromDocValues: true,
            },
          ],
          timeFieldName: 'order_date',
          metaFields: ['_source', '_id', '_type', '_index', '_score'],
          version: 'WzEzLDFd',
          originalSavedObjectBody: {
            title: 'kibana_sample_data_ecommerce',
            timeFieldName: 'order_date',
            fields:
              '[{"count":0,"name":"_id","type":"string","esTypes":["_id"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":false},{"count":0,"name":"_index","type":"string","esTypes":["_index"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":false},{"count":0,"name":"_score","type":"number","scripted":false,"searchable":false,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"_source","type":"_source","esTypes":["_source"],"scripted":false,"searchable":false,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"_type","type":"string","esTypes":["_type"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":false},{"count":0,"name":"category","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"category.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"category"}}},{"count":0,"name":"currency","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"customer_birth_date","type":"date","esTypes":["date"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"customer_first_name","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"customer_first_name.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"customer_first_name"}}},{"count":0,"name":"customer_full_name","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"customer_full_name.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"customer_full_name"}}},{"count":0,"name":"customer_gender","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"customer_id","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"customer_last_name","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"customer_last_name.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"customer_last_name"}}},{"count":0,"name":"customer_phone","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"day_of_week","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"day_of_week_i","type":"number","esTypes":["integer"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"email","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"event.dataset","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"geoip.city_name","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"geoip.continent_name","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"geoip.country_iso_code","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"geoip.location","type":"geo_point","esTypes":["geo_point"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"geoip.region_name","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"manufacturer","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"manufacturer.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"manufacturer"}}},{"count":0,"name":"order_date","type":"date","esTypes":["date"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"order_id","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products._id","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"products._id.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"products._id"}}},{"count":0,"name":"products.base_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.base_unit_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.category","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"products.category.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"products.category"}}},{"count":0,"name":"products.created_on","type":"date","esTypes":["date"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.discount_amount","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.discount_percentage","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.manufacturer","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"products.manufacturer.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"products.manufacturer"}}},{"count":0,"name":"products.min_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.product_id","type":"number","esTypes":["long"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.product_name","type":"string","esTypes":["text"],"scripted":false,"searchable":true,"aggregatable":false,"readFromDocValues":false},{"count":0,"name":"products.product_name.keyword","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true,"subType":{"multi":{"parent":"products.product_name"}}},{"count":0,"name":"products.quantity","type":"number","esTypes":["integer"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.sku","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.tax_amount","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.taxful_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.taxless_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"products.unit_discount_amount","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"sku","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"taxful_total_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"taxless_total_price","type":"number","esTypes":["half_float"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"total_quantity","type":"number","esTypes":["integer"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"total_unique_products","type":"number","esTypes":["integer"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"type","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true},{"count":0,"name":"user","type":"string","esTypes":["keyword"],"scripted":false,"searchable":true,"aggregatable":true,"readFromDocValues":true}]',
            fieldFormatMap:
              '{"taxful_total_price":{"id":"number","params":{"parsedUrl":{"origin":"http://localhost:5801","pathname":"/app/visualize","basePath":""},"pattern":"$0,0.[00]"}}}',
          },
          shortDotsEnable: false,
          fieldFormats: {
            fieldFormats: {},
            defaultMap: {
              ip: {
                id: 'ip',
                params: {},
              },
              date: {
                id: 'date',
                params: {},
              },
              date_nanos: {
                id: 'date_nanos',
                params: {},
                es: true,
              },
              number: {
                id: 'number',
                params: {},
              },
              boolean: {
                id: 'boolean',
                params: {},
              },
              _source: {
                id: '_source',
                params: {},
              },
              _default_: {
                id: 'string',
                params: {},
              },
            },
            metaParamsOptions: {},
          },
        },
      },
      dependencies: {
        legacy: {
          loadingCount$: {
            _isScalar: false,
            observers: [
              {
                closed: false,
                _parentOrParents: {
                  closed: false,
                  _parentOrParents: {
                    closed: false,
                    _parentOrParents: {
                      closed: false,
                      _parentOrParents: {
                        closed: false,
                        _parentOrParents: {
                          closed: false,
                          _parentOrParents: {
                            closed: false,
                            _parentOrParents: {
                              closed: false,
                              _parentOrParents: null,
                              _subscriptions: [null],
                              syncErrorValue: null,
                              syncErrorThrown: false,
                              syncErrorThrowable: true,
                              isStopped: false,
                              destination: {
                                closed: false,
                                _parentOrParents: null,
                                _subscriptions: null,
                                syncErrorValue: null,
                                syncErrorThrown: false,
                                syncErrorThrowable: false,
                                isStopped: false,
                                destination: {
                                  closed: true,
                                },
                                _context: {},
                              },
                            },
                            _subscriptions: [null],
                            syncErrorValue: null,
                            syncErrorThrown: false,
                            syncErrorThrowable: true,
                            isStopped: false,
                            count: 1,
                          },
                          _subscriptions: [null],
                          syncErrorValue: null,
                          syncErrorThrown: false,
                          syncErrorThrowable: true,
                          isStopped: false,
                          hasPrev: true,
                          prev: 0,
                        },
                        _subscriptions: [null],
                        syncErrorValue: null,
                        syncErrorThrown: false,
                        syncErrorThrowable: false,
                        isStopped: false,
                        parent: {
                          closed: true,
                          _parentOrParents: null,
                          _subscriptions: null,
                          syncErrorValue: null,
                          syncErrorThrown: false,
                          syncErrorThrowable: true,
                          isStopped: true,
                          concurrent: 1,
                          hasCompleted: true,
                          buffer: [],
                          active: 1,
                          index: 2,
                        },
                      },
                      _subscriptions: [null],
                      syncErrorValue: null,
                      syncErrorThrown: false,
                      syncErrorThrowable: false,
                      isStopped: false,
                      parent: {
                        closed: true,
                        _parentOrParents: null,
                        _subscriptions: null,
                        syncErrorValue: null,
                        syncErrorThrown: false,
                        syncErrorThrowable: false,
                        isStopped: true,
                        concurrent: 1,
                        hasCompleted: true,
                        buffer: [
                          {
                            _isScalar: false,
                          },
                        ],
                        active: 1,
                        index: 1,
                      },
                    },
                    _subscriptions: [
                      {
                        closed: false,
                        _subscriptions: [
                          {
                            closed: false,
                            _subscriptions: null,
                            subject: {
                              _isScalar: false,
                              observers: [
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 13,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 1,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 1,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                {
                                  closed: false,
                                  _parentOrParents: {
                                    closed: false,
                                    _parentOrParents: {
                                      closed: false,
                                      _parentOrParents: {
                                        closed: false,
                                        _parentOrParents: {
                                          closed: false,
                                          _parentOrParents: {
                                            closed: false,
                                            _parentOrParents: {
                                              closed: false,
                                              _parentOrParents: null,
                                              _subscriptions: [null],
                                              syncErrorValue: null,
                                              syncErrorThrown: false,
                                              syncErrorThrowable: true,
                                              isStopped: false,
                                              destination: {
                                                closed: false,
                                                _parentOrParents: null,
                                                _subscriptions: null,
                                                syncErrorValue: null,
                                                syncErrorThrown: false,
                                                syncErrorThrowable: false,
                                                isStopped: false,
                                                _context: {},
                                              },
                                            },
                                            _subscriptions: [null],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: true,
                                            isStopped: false,
                                            count: 3,
                                          },
                                          _subscriptions: [null],
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: false,
                                          hasPrev: true,
                                          prev: 0,
                                        },
                                        _subscriptions: [null],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                        parent: {
                                          closed: true,
                                          _parentOrParents: null,
                                          _subscriptions: null,
                                          syncErrorValue: null,
                                          syncErrorThrown: false,
                                          syncErrorThrowable: true,
                                          isStopped: true,
                                          concurrent: 1,
                                          hasCompleted: true,
                                          buffer: [],
                                          active: 1,
                                          index: 2,
                                        },
                                      },
                                      _subscriptions: [null],
                                      syncErrorValue: null,
                                      syncErrorThrown: false,
                                      syncErrorThrowable: false,
                                      isStopped: false,
                                      parent: {
                                        closed: true,
                                        _parentOrParents: null,
                                        _subscriptions: null,
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: true,
                                        concurrent: 1,
                                        hasCompleted: true,
                                        buffer: [
                                          {
                                            _isScalar: false,
                                          },
                                        ],
                                        active: 1,
                                        index: 1,
                                      },
                                    },
                                    _subscriptions: [
                                      null,
                                      {
                                        closed: false,
                                        _subscriptions: [
                                          {
                                            closed: false,
                                            _subscriptions: [
                                              {
                                                closed: false,
                                                _subscriptions: null,
                                                subject: {
                                                  _isScalar: false,
                                                  observers: [null],
                                                  closed: false,
                                                  isStopped: false,
                                                  hasError: false,
                                                  thrownError: null,
                                                  _value: 0,
                                                },
                                              },
                                            ],
                                            syncErrorValue: null,
                                            syncErrorThrown: false,
                                            syncErrorThrowable: false,
                                            isStopped: false,
                                            hasKey: true,
                                            key: 0,
                                          },
                                        ],
                                        syncErrorValue: null,
                                        syncErrorThrown: false,
                                        syncErrorThrowable: false,
                                        isStopped: false,
                                      },
                                    ],
                                    syncErrorValue: null,
                                    syncErrorThrown: false,
                                    syncErrorThrowable: false,
                                    isStopped: false,
                                    seenValue: false,
                                  },
                                  _subscriptions: [
                                    {
                                      closed: false,
                                      _subscriptions: null,
                                    },
                                  ],
                                  syncErrorValue: null,
                                  syncErrorThrown: false,
                                  syncErrorThrowable: false,
                                  isStopped: false,
                                },
                                null,
                              ],
                              closed: false,
                              isStopped: false,
                              hasError: false,
                              thrownError: null,
                            },
                          },
                        ],
                        syncErrorValue: null,
                        syncErrorThrown: false,
                        syncErrorThrowable: false,
                        isStopped: false,
                      },
                      null,
                    ],
                    syncErrorValue: null,
                    syncErrorThrown: false,
                    syncErrorThrowable: false,
                    isStopped: false,
                    seenValue: false,
                  },
                  _subscriptions: [null],
                  syncErrorValue: null,
                  syncErrorThrown: false,
                  syncErrorThrowable: false,
                  isStopped: false,
                },
                _subscriptions: [
                  {
                    closed: false,
                    _subscriptions: null,
                  },
                ],
                syncErrorValue: null,
                syncErrorThrown: false,
                syncErrorThrowable: false,
                isStopped: false,
                hasKey: true,
                key: 0,
              },
            ],
            closed: false,
            isStopped: false,
            hasError: false,
            thrownError: null,
            _value: 0,
          },
        },
      },
    },
    aggs: {
      typesRegistry: {},
      bySchemaName: () => [
        {
          id: '1',
          enabled: true,
          type: 'sum',
          params: {
            field: 'total_quantity',
          },
          schema: 'metric',
          makeLabel: () => 'Total quantity',
          toSerializedFieldFormat: () => ({
            id: 'number',
            params: {
              parsedUrl: {
                origin: 'http://localhost:5801',
                pathname: '/app/visualize',
                basePath: '',
              },
            },
          }),
        },
      ],
      getResponseAggs: () => [
        {
          id: '1',
          enabled: true,
          type: { name: 'sum' },
          params: {
            field: 'total_quantity',
          },
          schema: 'metric',
          toSerializedFieldFormat: () => ({
            id: 'number',
            params: {
              parsedUrl: {
                origin: 'http://localhost:5801',
                pathname: '/app/visualize',
                basePath: '',
              },
            },
          }),
        },
        {
          id: '2',
          enabled: true,
          type: { name: 'date_histogram' },
          params: {
            field: 'order_date',
            timeRange: {
              from: '2020-09-30T12:41:13.795Z',
              to: '2020-10-15T17:00:00.000Z',
            },
            useNormalizedEsInterval: true,
            scaleMetricValues: false,
            interval: 'auto',
            drop_partials: false,
            min_doc_count: 1,
            extended_bounds: {},
          },
          schema: 'segment',
          buckets: {
            getInterval: () => ({ esUnit: 'h', esValue: '1' }),
            getScaledDateFormat: () => ({}),
            getBounds: () => ({}),
            setBounds: () => {},
            setInterval: () => {},
          },
          fieldIsTimeField: () => false,
          toSerializedFieldFormat: () => ({
            id: 'date',
            params: { pattern: 'HH:mm:ss.SSS' },
          }),
        },
        {
          id: '3',
          enabled: true,
          type: { name: 'terms' },
          params: {
            field: 'category.keyword',
            orderBy: '1',
            order: 'desc',
            size: 5,
            otherBucket: false,
            otherBucketLabel: 'Other',
            missingBucket: false,
            missingBucketLabel: 'Missing',
          },
          schema: 'group',
          toSerializedFieldFormat: () => ({
            id: 'terms',
            params: {
              id: 'string',
              otherBucketLabel: 'Other',
              missingBucketLabel: 'Missing',
              parsedUrl: {
                origin: 'http://localhost:5801',
                pathname: '/app/visualize',
                basePath: '',
              },
            },
          }),
        },
      ],
    },
  },
  isHierarchical: () => false,
  uiState: {
    vis: {
      legendOpen: false,
    },
    get: mockUiStateGet,
  },
};
