/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import { i18n } from '@kbn/i18n';
import { ControlFactory, DefaultControlApi } from './controls/types';

const registry: { [key: string]: () => Promise<ControlFactory<any, any>> } = {};

export const registerControlFactory = <
  State extends object = object,
  ApiType extends DefaultControlApi = DefaultControlApi
>(
  type: string,
  getFactory: () => Promise<ControlFactory<State, ApiType>>
) => {
  if (registry[type] !== undefined)
    throw new Error(
      i18n.translate('controls.controlFactoryRegistry.factoryAlreadyExistsError', {
        defaultMessage: 'A control factory for type: {key} is already registered.',
        values: { key: type },
      })
    );
  registry[type] = getFactory as () => Promise<ControlFactory<any, any>>;
};

export const getControlFactory = async <
  State extends object = object,
  ApiType extends DefaultControlApi = DefaultControlApi
>(
  key: string
): Promise<ControlFactory<State, ApiType>> => {
  if (registry[key] === undefined)
    throw new Error(
      i18n.translate('controls.controlFactoryRegistry.factoryNotFoundError', {
        defaultMessage: 'No control factory found for type: {key}',
        values: { key },
      })
    );
  return (await registry[key]()) as ControlFactory<State, ApiType>;
};

export const getAllControlTypes = () => {
  return Object.keys(registry);
};
