/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import { of } from 'rxjs';
import type { MockedKeys } from '@kbn/utility-types-jest';
import { uiSettingsServiceMock } from '@kbn/core/public/mocks';
import { DataViewsContract } from '@kbn/data-views-plugin/common';

import { SearchSource, SearchSourceDependencies } from './search_source';
import { ISearchStartSearchSource, ISearchSource, SearchSourceFields } from './types';

export const searchSourceInstanceMock: MockedKeys<ISearchSource> = {
  setOverwriteDataViewType: jest.fn(),
  setField: jest.fn().mockReturnThis(),
  removeField: jest.fn().mockReturnThis(),
  getId: jest.fn(),
  getFields: jest.fn(),
  getField: jest.fn(),
  getOwnField: jest.fn(),
  create: jest.fn().mockReturnThis(),
  createCopy: jest.fn().mockReturnThis(),
  createChild: jest.fn().mockReturnThis(),
  setParent: jest.fn(),
  getParent: jest.fn().mockReturnThis(),
  fetch$: jest.fn().mockReturnValue(of({})),
  fetch: jest.fn().mockResolvedValue({}),
  onRequestStart: jest.fn(),
  getSearchRequestBody: jest.fn(),
  destroy: jest.fn(),
  history: [],
  getSerializedFields: jest.fn(),
  serialize: jest.fn(),
  toExpressionAst: jest.fn(),
  getActiveIndexFilter: jest.fn(),
  parseActiveIndexPatternFromQueryString: jest.fn(),
  loadDataViewFields: jest.fn(),
};

export const searchSourceCommonMock: jest.Mocked<ISearchStartSearchSource> = {
  create: jest.fn().mockReturnValue(searchSourceInstanceMock),
  createLazy: jest.fn().mockReturnValue(searchSourceInstanceMock),
  createEmpty: jest.fn().mockReturnValue(searchSourceInstanceMock),
  telemetry: jest.fn(),
  getAllMigrations: jest.fn(),
  inject: jest.fn(),
  extract: jest.fn(),
};

export const createSearchSourceMock = (
  fields?: SearchSourceFields,
  response?: any,
  search?: jest.Mock
) =>
  new SearchSource(fields, {
    aggs: {
      createAggConfigs: jest.fn(),
    } as unknown as SearchSourceDependencies['aggs'],
    getConfig: uiSettingsServiceMock.createStartContract().get,
    search:
      search ||
      jest.fn().mockReturnValue(
        of(
          response ?? {
            rawResponse: { hits: { hits: [], total: 0 } },
            isPartial: false,
            isRunning: false,
          }
        )
      ),
    onResponse: jest.fn().mockImplementation((req, res) => res),
    scriptedFieldsEnabled: true,
    dataViews: {
      getMetaFields: jest.fn(),
      getShortDotsEnable: jest.fn(),
    } as unknown as DataViewsContract,
  });
