/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import type {
  SqlGetAsyncRequest,
  SqlQueryRequest,
  SqlQueryResponse,
} from '@elastic/elasticsearch/lib/api/types';
import type { IKibanaSearchResponse, IKibanaSearchRequest } from '@kbn/search-types';

export const SQL_SEARCH_STRATEGY = 'sql';

export type SqlRequestParams = (
  | Omit<SqlQueryRequest, 'keep_alive' | 'keep_on_completion'>
  | Omit<SqlGetAsyncRequest, 'id' | 'keep_alive' | 'keep_on_completion'>
) & {
  /**
   * Does not close the cursor on search completion.
   */
  keep_cursor?: boolean;
};
export type SqlSearchStrategyRequest = IKibanaSearchRequest<SqlRequestParams>;

export interface SqlSearchStrategyResponse extends IKibanaSearchResponse<SqlQueryResponse> {
  /**
   * A metric showing how long did the search take.
   */
  took: number;
}
