/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

import { i18n } from '@kbn/i18n';
import { TutorialsCategory, TutorialSchema } from '../../services/tutorials';
import {
  onPremInstructions,
  cloudInstructions,
  onPremCloudInstructions,
} from '../instructions/metricbeat_instructions';
import { TutorialContext } from '../../services/tutorials/lib/tutorials_registry_types';

export function traefikMetricsSpecProvider(context: TutorialContext): TutorialSchema {
  const moduleName = 'traefik';
  return {
    id: 'traefikMetrics',
    name: i18n.translate('home.tutorials.traefikMetrics.nameTitle', {
      defaultMessage: 'Traefik Metrics',
    }),
    moduleName,
    category: TutorialsCategory.METRICS,
    shortDescription: i18n.translate('home.tutorials.traefikMetrics.shortDescription', {
      defaultMessage: 'Collect metrics from Traefik with Metricbeat.',
    }),
    longDescription: i18n.translate('home.tutorials.traefikMetrics.longDescription', {
      defaultMessage:
        'The `traefik` Metricbeat module fetches metrics from Traefik. \
[Learn more]({learnMoreLink}).',
      values: {
        learnMoreLink: '{config.docs.beats.metricbeat}/metricbeat-module-traefik.html',
      },
    }),
    euiIconType: context.staticAssets.getPluginAssetHref('/logos/traefik.svg'),
    artifacts: {
      dashboards: [],
      exportedFields: {
        documentationUrl: '{config.docs.beats.metricbeat}/exported-fields-traefik.html',
      },
    },
    completionTimeMinutes: 10,
    onPrem: onPremInstructions(moduleName, context),
    elasticCloud: cloudInstructions(moduleName, context),
    onPremElasticCloud: onPremCloudInstructions(moduleName, context),
    integrationBrowserCategories: ['observability'],
  };
}
